orca r3519 - in trunk: . test/keystrokes/firefox



Author: joanied
Date: Tue Jan 29 07:15:52 2008
New Revision: 3519
URL: http://svn.gnome.org/viewvc/orca?rev=3519&view=rev

Log:
More regression test updates.


Modified:
   trunk/ChangeLog
   trunk/test/keystrokes/firefox/html_role_combo_box.py
   trunk/test/keystrokes/firefox/xul_role_combo_box.py
   trunk/test/keystrokes/firefox/xul_role_menu_bar.py
   trunk/test/keystrokes/firefox/xul_role_push_button.py
   trunk/test/keystrokes/firefox/xul_role_radio_button.py
   trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py

Modified: trunk/test/keystrokes/firefox/html_role_combo_box.py
==============================================================================
--- trunk/test/keystrokes/firefox/html_role_combo_box.py	(original)
+++ trunk/test/keystrokes/firefox/html_role_combo_box.py	Tue Jan 29 07:15:52 2008
@@ -174,7 +174,7 @@
     "Return to collapse combo box",
     ["BRAILLE LINE:  'WONTFIX Combo'",
      "     VISIBLE:  'WONTFIX Combo', cursor=1",
-     "SPEECH OUTPUT: 'Minefield application Combo Box Regression Test - Minefield frame Combo Box Regression Test internal frame'",
+     "SPEECH OUTPUT: 'Minefield application Minefield frame about:blank internal frame'",
      "SPEECH OUTPUT: 'Resolution: WONTFIX combo box'"]))
 
 ########################################################################
@@ -265,7 +265,7 @@
     "Return to collapse combo box",
     ["BRAILLE LINE:  'Braille Combo'",
      "     VISIBLE:  'Braille Combo', cursor=1",
-     "SPEECH OUTPUT: 'Minefield application Combo Box Regression Test - Minefield frame Combo Box Regression Test internal frame'",
+     "SPEECH OUTPUT: 'Minefield application Minefield frame about:blank internal frame'",
      "SPEECH OUTPUT: 'Component Braille combo box'"]))
 
 ########################################################################

Modified: trunk/test/keystrokes/firefox/xul_role_combo_box.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_combo_box.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_combo_box.py	Tue Jan 29 07:15:52 2008
@@ -16,44 +16,10 @@
 ########################################################################
 # Open the "Edit" menu and Up Arrow to Preferences, then press Return.
 #
-sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt>e"))
-sequence.append(utils.AssertPresentationAction(
-    "Edit menu",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Edit Menu'",
-     "     VISIBLE:  'Edit Menu', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar Select All(Control A)'",
-     "     VISIBLE:  'Select All(Control A)', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Edit menu'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Select All Control A'"]))
-
-sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
-sequence.append(utils.AssertPresentationAction(
-    "Up Arrow in Edit menu",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar Preferences'",
-     "     VISIBLE:  'Preferences', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Preferences'"]))
-
-sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Return"))
-sequence.append(utils.AssertPresentationAction(
-    "Press Return to make the Preferences dialog appear",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar AutoComplete Location  $l'",
-     "     VISIBLE:  'Location  $l', cursor=10",
-     "BRAILLE LINE:  'Minefield Application Minefield Preferences Frame'",
-     "     VISIBLE:  'Minefield Preferences Frame', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Minefield Preferences Frame List Main ListItem'",
-     "     VISIBLE:  'Main ListItem', cursor=1",
-     "SPEECH OUTPUT: 'Location autocomplete'",
-     "SPEECH OUTPUT: 'Location text '",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Minefield Preferences frame'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Main list item'"]))
+sequence.append(WaitForWindowActivate("Minefield Preferences",None))
 
 ########################################################################
 # Press Tab to move to the "When Minefield starts" combo box.  This combo

Modified: trunk/test/keystrokes/firefox/xul_role_menu_bar.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_menu_bar.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_menu_bar.py	Tue Jan 29 07:15:52 2008
@@ -43,24 +43,24 @@
     "Right Arrow on menu bar",
     ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Edit Menu'",
      "     VISIBLE:  'Edit Menu', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar Select All(Control A)'",
-     "     VISIBLE:  'Select All(Control A)', cursor=1",
+     "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar Undo grayed(Control Z)'",
+     "     VISIBLE:  'Undo grayed(Control Z)', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Edit menu'",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Select All Control A'"]))
+     "SPEECH OUTPUT: 'Undo grayed Control Z'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Right"))
 sequence.append(utils.AssertPresentationAction(
     "Right Arrow on menu bar",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar View Menu'",
-     "     VISIBLE:  'View Menu', cursor=1",
+    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar AutoComplete Location  $l'",
+     "     VISIBLE:  'Location  $l', cursor=10",
      "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar Toolbars Menu'",
      "     VISIBLE:  'Toolbars Menu', cursor=1",
-     "SPEECH OUTPUT: ''",
+     "SPEECH OUTPUT: 'Location autocomplete'",
+     "SPEECH OUTPUT: 'Location text '",
      "SPEECH OUTPUT: 'View menu'",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Toolbars menu'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -90,12 +90,12 @@
     "Left Arrow on menu bar",
     ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Edit Menu'",
      "     VISIBLE:  'Edit Menu', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar Select All(Control A)'",
-     "     VISIBLE:  'Select All(Control A)', cursor=1",
+     "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar Paste(Control V)'",
+     "     VISIBLE:  'Paste(Control V)', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Edit menu'",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Select All Control A'"]))
+     "SPEECH OUTPUT: 'Paste Control V'"]))
 
 ########################################################################
 # Dismiss the menu by pressing Escape and wait for the location bar

Modified: trunk/test/keystrokes/firefox/xul_role_push_button.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py	(original)
+++ trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py	Tue Jan 29 07:15:52 2008
@@ -21,7 +21,7 @@
 sequence.append(KeyComboAction("<Alt>f"))
 
 sequence.append(KeyComboAction("p"))
-sequence.append(WaitForWindowActivate("Print",None))
+sequence.append(PauseAction(3000))
 
 ########################################################################
 # Read the title bar with Orca+KP_ENTER



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/test/keystrokes/firefox/xul_role_push_button.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_push_button.py	Tue Jan 29 07:15:52 2008
@@ -14,86 +14,22 @@
 sequence.append(WaitForWindowActivate("Minefield",None))
 
 ########################################################################
 # Open the "File" menu and press U for the Page Setup dialog
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt>f"))
-sequence.append(utils.AssertPresentationAction(
-    "File menu",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar File Menu'",
-     "     VISIBLE:  'File Menu', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar New Window(Control N)'",
-     "     VISIBLE:  'New Window(Control N)', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'File menu'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'New Window Control N'"]))
-
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("u"))
-sequence.append(utils.AssertPresentationAction(
-    "u for Page Setup",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar AutoComplete Location  $l'",
-     "     VISIBLE:  'Location  $l', cursor=10",
-     "BRAILLE LINE:  'Minefield Application Page Setup Dialog'",
-     "     VISIBLE:  'Page Setup Dialog', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
-     "     VISIBLE:  '&=y Portrait RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Location autocomplete'",
-     "SPEECH OUTPUT: 'Location text '",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Page Setup %'",
-     "SPEECH OUTPUT: 'Format panel Orientation: panel'",
-     "SPEECH OUTPUT: 'Portrait selected radio button'"]))
- 
-sequence.append(WaitForWindowActivate("Page Setup",None))
-
-########################################################################
-# In the Page Setup dialog, shift+tab once to move to the page tabs.
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("<Shift>ISO_Left_Tab"))
-sequence.append(utils.AssertPresentationAction(
-    "Shift+Tab to page tabs",
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog Format & Options Page'",
-     "     VISIBLE:  'Format & Options Page', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Format & Options page'"]))
-
-########################################################################
-# Shift+tab again to move to the OK push button. 
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("<Shift>ISO_Left_Tab"))
-sequence.append(utils.AssertPresentationAction(
-    "Shift+Tab to OK button",
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog OK Button'",
-     "     VISIBLE:  'OK Button', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'OK button'"]))
 
-########################################################################
-# Do a basic "Where Am I" via KP_Enter. 
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("KP_Enter"))
+sequence.append(KeyComboAction("p"))
 sequence.append(PauseAction(3000))
-sequence.append(utils.AssertPresentationAction(
-    "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog OK Button'",
-     "     VISIBLE:  'OK Button', cursor=1",
-     "SPEECH OUTPUT: 'OK'",
-     "SPEECH OUTPUT: 'button'",
-     "SPEECH OUTPUT: ''"]))
 
 ########################################################################
 # Shift+tab again to move to the Cancel push button. 
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Shift>ISO_Left_Tab"))
 sequence.append(utils.AssertPresentationAction(
-    "Shift+Tab to Cancel button",
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog Cancel Button'",
+    "Shift+Tab to button",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog Cancel Button'",
      "     VISIBLE:  'Cancel Button', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Cancel button'"]))
@@ -106,18 +42,18 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog Cancel Button'",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog Cancel Button'",
      "     VISIBLE:  'Cancel Button', cursor=1",
      "SPEECH OUTPUT: 'Cancel'",
      "SPEECH OUTPUT: 'button'",
-     "SPEECH OUTPUT: ''"]))
+     "SPEECH OUTPUT: 'Alt c'"]))
 
 ########################################################################
 # Dismiss the dialog by pressing Space on the Cancel button and wait 
 # for the location bar to regain focus.
 #
 sequence.append(TypeAction(" "))
-sequence.append(WaitForFocus("Location", acc_role=pyatspi.ROLE_ENTRY))
+sequence.append(WaitForWindowActivate("Minefield",None))
 
 # Just a little extra wait to let some events get through.
 #
@@ -14,86 +14,22 @@
 
 ########################################################################
-# Open the "File" menu and press U for the Page Setup dialog
+# Open the "File" menu and press P for the Print dialog
 #
 sequence.append(utils.StartRecordingAction())
@@ -14,86 +14,22 @@
 
 ########################################################################
-# Shift+tab again to move to the Cancel push button. 
+# In the Print dialog, shift+tab to move to the push button.
 #
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/xul_role_radio_button.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_radio_button.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_radio_button.py	Tue Jan 29 07:15:52 2008
@@ -11,55 +11,27 @@
 ########################################################################
 # We wait for the focus to be on a blank Firefox window.
 #
-sequence.append(WaitForWindowActivate("Minefield",None))
+sequence.append(WaitForWindowActivate("Minefield", None))
 
 ########################################################################
 # Open the "File" menu and press U for the Page Setup dialog
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt>f"))
-sequence.append(utils.AssertPresentationAction(
-    "File menu",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar File Menu'",
-     "     VISIBLE:  'File Menu', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar New Window(Control N)'",
-     "     VISIBLE:  'New Window(Control N)', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'File menu'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'New Window Control N'"]))
 
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("u"))
-sequence.append(utils.AssertPresentationAction(
-    "u for Page Setup",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar AutoComplete Location  $l'",
-     "     VISIBLE:  'Location  $l', cursor=10",
-     "BRAILLE LINE:  'Minefield Application Page Setup Dialog'",
-     "     VISIBLE:  'Page Setup Dialog', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
-     "     VISIBLE:  '&=y Portrait RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Location autocomplete'",
-     "SPEECH OUTPUT: 'Location text '",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Page Setup %'",
-     "SPEECH OUTPUT: 'Format panel Orientation: panel'",
-     "SPEECH OUTPUT: 'Portrait selected radio button'"]))
- 
-sequence.append(WaitForWindowActivate("Page Setup",None))
+sequence.append(KeyComboAction("p"))
 
 ########################################################################
-# In the Page Setup dialog, focus should already be on the "Portrait"
-# radio button.  Right Arrow to the "Landscape" radio button.
+# Press Alt A to jump to the radio button group
 #
 sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Right"))
+sequence.append(KeyComboAction("<Alt>a"))
 sequence.append(utils.AssertPresentationAction(
-    "Right Arrow to Landscape",
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Landscape RadioButton'",
-     "     VISIBLE:  '&=y Landscape RadioButton', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Landscape selected radio button'"]))
+    "Alt a to radio button group",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page Print Pages Filler &=y All RadioButton'",
+     "     VISIBLE:  '&=y All RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'Print Pages'",
+     "SPEECH OUTPUT: 'All selected radio button'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter. 
@@ -69,25 +41,25 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Landscape RadioButton'",
-     "     VISIBLE:  '&=y Landscape RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Orientation:'",
-     "SPEECH OUTPUT: 'Landscape radio button'",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page Print Pages Filler &=y All RadioButton'",
+     "     VISIBLE:  '&=y All RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'Print Pages'",
+     "SPEECH OUTPUT: 'All radio button'",
      "SPEECH OUTPUT: 'selected'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: ''"]))
+     "SPEECH OUTPUT: 'item 1 of 3'",
+     "SPEECH OUTPUT: 'Alt a'"]))
 
 ########################################################################
 # Left Arrow to return to the "Portrait" radio button. 
 #
 sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Left"))
+sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
-    "Left Arrow to Portrait",
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
-     "     VISIBLE:  '&=y Portrait RadioButton', cursor=1",
+    "Down Arrow to next radio button",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page Print Pages Filler & y Range RadioButton'",
+     "     VISIBLE:  '& y Range RadioButton', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Portrait selected radio button'"]))
+     "SPEECH OUTPUT: 'Range not selected radio button'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter. 
@@ -97,13 +69,13 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
-     "     VISIBLE:  '&=y Portrait RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Orientation:'",
-     "SPEECH OUTPUT: 'Portrait radio button'",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page Print Pages Filler &=y Range RadioButton'",
+     "     VISIBLE:  '&=y Range RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'Print Pages'",
+     "SPEECH OUTPUT: 'Range radio button'",
      "SPEECH OUTPUT: 'selected'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: ''"]))
+     "SPEECH OUTPUT: 'item 3 of 3'",
+     "SPEECH OUTPUT: 'Alt n'"]))
 
 ########################################################################
 # Dismiss the dialog by pressing Escape and wait for the location bar
@@ -11,55 +11,27 @@
 
 ########################################################################
-# Open the "File" menu and press U for the Page Setup dialog
+# Open the "File" menu and press P for the Print dialog
 #
 sequence.append(utils.StartRecordingAction())
@@ -69,25 +41,25 @@
 
 ########################################################################
-# Left Arrow to return to the "Portrait" radio button. 
+# Down Arrow to the next radio button.
 #
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py
==============================================================================